@@ -173,16 +173,18 @@ sub _vmem_usage {
 	my $stderr = $run->_stderr;
 	my $cmd  = "tail -3 $stderr";
 	my @last = `$cmd`;
+	my $msg;
 	my $consider_vmem_retry_reason =
-          ($last[-1] =~ /Out of memory\!/)            ? "found stderr: $last[-1]"
-        : ($last[-1] =~ /(MemoryError)|(Cannot allocate memory)/)
-                                                      ? "found stderr: $last[-1]"
-        : ($last[-2] =~ /^Error: cannot allocate vector of size /
-            && $last[-1] =~ /Execution halted/)       ? "found stderr: $last[-2]"
-        : ($pct >= $self->retry_mem_percent)          ? "exceeded allocated memory limit (or close enough to the limit)"
-        : $self->memory_too_small->($stats, $stderr)  ? "user-provided check"
-                                                      : undef;
-
+		  ($last[-1] =~ /Out of memory\!/)            ? "found stderr: $last[-1]"
+		: ($last[-1] =~ /(MemoryError)|(Cannot allocate memory)/)
+													  ? "found stderr: $last[-1]"
+		: ($last[-2] =~ /^Error: cannot allocate vector of size /
+			&& $last[-1] =~ /Execution halted/)       ? "found stderr: $last[-2]"
+		: ($msg = `grep 'java.lang.OutOfMemoryError: GC overhead limit exceeded' $stderr`)
+													  ? "found stderr: $msg"
+		: ($pct >= $self->retry_mem_percent)          ? "exceeded allocated memory limit (or close enough to the limit)"
+		: $self->memory_too_small->($stats, $stderr)  ? "user-provided check"
+		:                                               undef;
 	if ($consider_vmem_retry_reason) {
 		$self->info( "Considering vmem retry, $consider_vmem_retry_reason" );
 		return $self->_can_retry_from_vmem(
